@@ -6,21 +6,22 @@ from ..base import BaseModel
 # https://vk.com/dev/objects/post_source
 
 
-class Type(Enum):
+class Type(str, Enum):
     vk = 'vk'
+    mvk = 'mvk'
     widget = 'widget'
     api = 'api'
     rss = 'rss'
     sms = 'sms'
 
 
-class Platform(Enum):
+class Platform(str, Enum):
     android = 'android'
     iphone = 'iphone'
     wphone = 'wphone'
 
 
-class Data(Enum):
+class Data(str, Enum):
     profile_activity = 'profile_activity'
     profile_photo = 'profile_photo'
     comments = 'comments'
