@@ -12,7 +12,7 @@ from .additional import PostSource, Donut
 class WallPostComments(BaseModel):
     count: int
     can_post: int
-    groups_can_post: int
+    groups_can_post: Optional[int]
     can_close: Optional[bool]
     can_open: Optional[bool]
 
@@ -28,7 +28,7 @@ class View(BaseModel):
     count: int
 
 
-class PostType(Enum):
+class PostType(str, Enum):
     post = 'post'
     copy = 'copy'
     reply = 'reply'
@@ -46,22 +46,26 @@ class WallPost(BaseModel):
     reply_owner_id: Optional[int]
     reply_post_id: Optional[int]
     friends_only: Optional[int]
-    comments: WallPostComments
+    comments: Optional[WallPostComments]
     copyright: Optional[Copyright]
-    likes: Like
-    reposts: Repost
-    views: View
+    likes: Optional[Like]
+    reposts: Optional[Repost]
+    views: Optional[View]
     post_type: PostType
     post_source: PostSource
-    attachments: List[Attachment]
+    attachments: Optional[List[Attachment]]
     geo: Optional[Geo]
     signer_id: Optional[int]
-    copy_history: Optional['WallPost']
+    copy_history: Optional[List['WallPost']]
     can_pin: Optional[int]
     can_delete: Optional[int]
     can_edit: Optional[int]
     is_pinned: Optional[int]
-    marked_as_ads: int
-    is_favorite: bool
+    marked_as_ads: Optional[int]
+
+    is_favorite: Optional[bool]
     donut: Optional[Donut]
     postponed_id: Optional[int]
+
+
+WallPost.update_forward_refs()
